Index: src/wp-includes/class-wp-block-patterns-registry.php
===================================================================
--- src/wp-includes/class-wp-block-patterns-registry.php	(revision 48335)
+++ src/wp-includes/class-wp-block-patterns-registry.php	(working copy)
@@ -33,7 +33,7 @@
 	 * @since 5.5.0
 	 *
 	 * @param string $pattern_name       Pattern name including namespace.
 	 * @param array  $pattern_properties Array containing the properties of the pattern: label, content.
 	 * @return bool True if the pattern was registered with success and false otherwise.
 	 */
 	public function register( $pattern_name, $pattern_properties ) {
@@ -42,6 +42,16 @@
 			return false;
 		}
 
+		if ( ! isset( $pattern_properties['title'] ) || ! is_string( $pattern_properties['title'] ) ) {
+			_doing_it_wrong( __METHOD__, __( 'Pattern title must be a string.' ), '5.5.0' );
+			return false;
+		}
+
+		if ( ! isset( $pattern_properties['content'] ) || ! is_string( $pattern_properties['content'] ) ) {
+			_doing_it_wrong( __METHOD__, __( 'Pattern content must be a string.' ), '5.5.0' );
+			return false;
+		}
+
 		$this->registered_patterns[ $pattern_name ] = array_merge(
 			$pattern_properties,
 			array( 'name' => $pattern_name )
@@ -33,7 +33,7 @@
 	 *
 	 * @param string $pattern_name       Pattern name including namespace.
-	 * @param array  $pattern_properties Array containing the properties of the pattern: label, content.
+	 * @param array  $pattern_properties Array containing the properties of the pattern: Title, content, description, viewportWidth, categories, keywords.
 	 * @return bool True if the pattern was registered with success and false otherwise.
 	 */
